cubature-package: Cubature is a package for adaptive multidimensional integration over
hypercubes
Description
Cubature is a package for adaptive multidimensional integration over
hypercubes. It is a wrapper around the pure C, GPLed implementation by
Steven G. Johnson available from the URL
http://ab-initio.mit.edu/wiki/index.php/Cubature.
Details
| Package: |
| cubature |
| Type: |
| Package |
| Version: |
|
1.0 |
| Date: |
| 2009-12-17 |
| License: |
| GPL V2 or later |
| LazyLoad:
|
| yes |
There is only one function in the package called
adaptIntegrate.